@@ -24,25 +24,18 @@ class CSVHeaders(CmkUtil):
     def add_arguments(self):
         self.argparser.add_argument(
             "--HA",
-            "--add-generic-headers",
-            dest="add_generic_headers",
+            "--add-headers",
+            dest="add_headers",
             action="store_true",
             help="""Add/prepend headers to the given data, in generic 'field_%%d' format, e.g. 'field_1', 'field_2', etc.""",
         )
 
         self.argparser.add_argument(
-            "--HM",
-            "--make-generic-headers",
-            dest="make_generic_headers",
+            "--HZ",
+            "--zap-headers",
+            dest="zap_headers",
             action="store_true",
-            help="Similar to `--HA/--add-generic-headers`, but instead of adding, replace current headers with generic 'field_%%d' format, e.g. 'field_1', 'field_2', etc. ",
-        )
-
-        self.argparser.add_argument(
-            "-P",
-            "--preview",
-            action="store_true",
-            help="""Output only the list of headers; use this to preview renamed or otherwise transformed headers without including the rest of the data""",
+            help="""Similar to `--HA/--add-headers`, but instead of adding a generic header row, completely replace (i.e. "zap") the current headers""",
         )
 
         self.argparser.add_argument(
@@ -50,23 +43,31 @@ class CSVHeaders(CmkUtil):
             "--rename",
             dest="rename_headers",
             type=str,
-            help="""comma-delimited list of header|new_name TK """,
+            help="""Comma-delimited list of pipe-delimited pairs:  (existing) column names/ids, and their replacement, e.g. 'col_a|new_a,2|new_b,"3|New C Col"'  """,
         )
 
         self.argparser.add_argument(
             "-S",
-            "--slug",
-            dest="slug_mode",
+            "--slugify",
+            dest="slugify_mode",
             action="store_true",
-            help=""" slug the headers in snakecase TK""",
+            help="""Convert all the headers into snakecase, e.g. 'Date-Time ' becomes 'date_time' """,
         )
 
         self.argparser.add_argument(
-            "--sed",
-            dest="sed_headers",
+            "-X",
+            "--regex",
+            dest="regex_headers",
             nargs=2,
             type=str,
-            help="""Apply a regex replacement to each header""",
+            help="""Apply a regex replacement to each header: '[PATTERN]' '[REPLACEMENT]'""",
+        )
+
+        self.argparser.add_argument(
+            "-P",
+            "--preview",
+            action="store_true",
+            help="""Output only the list of headers; use this to preview renamed or otherwise transformed headers without processing the entire input data file""",
         )
 
     @staticmethod
@@ -100,8 +101,8 @@ class CSVHeaders(CmkUtil):
         if not any(
             h
             for h in (
-                self.args.make_generic_headers,
-                self.args.add_generic_headers,
+                self.args.zap_headers,
+                self.args.add_headers,
             )
         ):
             self.generic_columnized = False
@@ -112,7 +113,7 @@ class CSVHeaders(CmkUtil):
             _row = next(rows)
             column_names = [f"field_{i}" for i, _c in enumerate(_row, self.start_index)]
 
-            if self.args.add_generic_headers:
+            if self.args.add_headers:
                 # then first row (_row) is actually data, not headers to be replaced
                 rows = itertools.chain([_row], rows)
 
@@ -122,7 +123,7 @@ class CSVHeaders(CmkUtil):
         )
 
     def _set_modes(self, column_names=typeList[str]) -> typeNoReturn:
-        self.slug_mode = True if self.args.slug_mode else False
+        self.slugify_mode = True if self.args.slugify_mode else False
 
         if self.args.rename_headers:
             self.rename_headers = self.parse_rename_param(
@@ -131,8 +132,8 @@ class CSVHeaders(CmkUtil):
         else:
             self.rename_headers = False
 
-        if self.args.sed_headers:
-            _pat, _rep = self.args.sed_headers
+        if self.args.regex_headers:
+            _pat, _rep = self.args.regex_headers
             self.sed_pattern = re.compile(_pat)
             self.sed_replace = _rep
         else:
@@ -143,10 +144,10 @@ class CSVHeaders(CmkUtil):
         elif any(
             m
             for m in (
-                self.slug_mode,
+                self.slugify_mode,
                 self.rename_headers,
                 self.sed_pattern,
-                self.args.add_generic_headers,
+                self.args.add_headers,
                 self.generic_columnized,
             )
         ):
@@ -181,7 +182,7 @@ class CSVHeaders(CmkUtil):
             for i, colname in enumerate(column_names):
                 column_names[i] = self.sed_pattern.sub(self.sed_replace, colname)
 
-        if self.slug_mode:
+        if self.slugify_mode:
             for i, colname in enumerate(column_names):
                 column_names[i] = slugify(colname)
 
