@@ -1,3 +1,4 @@
+from io import StringIO
 from unittest.mock import patch
 from unittest import skip as skiptest
 import sys
@@ -8,7 +9,7 @@ from csvmedkit.moreutils.csvheaders import (
     launch_new_instance,
 )
 
-from tests.tk import CSVKitTestCase, EmptyFileTests
+from tests.tk import CSVKitTestCase, EmptyFileTests, stdin_as_string
 
 
 class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
@@ -45,7 +46,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
 
     def test_add_generic_headers(self):
         self.assertLines(
-            ["--add-generic-headers", "examples/dummy.csv"],
+            ["--add-headers", "examples/dummy.csv"],
             [
                 "field_1,field_2,field_3",
                 "a,b,c",
@@ -62,9 +63,19 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
             ],
         )
 
-    def test_make_generic_headers(self):
+    def test_add_craploads_of_generic_headers(self):
+        txt = ",".join(str(i) for i in range(100))
+        infile = StringIO(f"{txt}\n")
+        with stdin_as_string(infile):
+            self.assertLines(
+                ["--add-headers"],
+                [",".join(f"field_{i}" for i in range(1, 101)), txt],
+            )
+        infile.close()
+
+    def test_zap_headers(self):
         self.assertLines(
-            ["--make-generic-headers", "examples/dummy.csv"],
+            ["--zap-headers", "examples/dummy.csv"],
             [
                 "field_1,field_2,field_3",
                 "1,2,3",
@@ -72,7 +83,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
         )
 
         self.assertLines(
-            ["--HM", "--zero", "examples/dummy.csv"],
+            ["--HZ", "--zero", "examples/dummy.csv"],
             [
                 "field_0,field_1,field_2",
                 "1,2,3",
@@ -189,17 +200,22 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
 
     def test_sed(self):
         self.assertLines(
-            ["--sed", r"(\w)", r"_\1_", "examples/dummy.csv"], ["_a_,_b_,_c_", "1,2,3"]
+            ["-X", r"(\w)", r"_\1_", "examples/dummy.csv"], ["_a_,_b_,_c_", "1,2,3"]
         )
 
-    def test_slug_mode(self):
+    def test_slugify_mode(self):
         self.assertLines(
-            ["--slug", "examples/heady.csv"], ["a,b_sharps,c_sea_shells", "1,2,3"]
+            ["--slugify", "examples/heady.csv"],
+            [
+                "a,b_sharps,sea_shells",
+                "100,cats,Iowa",
+                "200,dogs,Ohio",
+            ],
         )
 
     def test_preview_mode(self):
         """
-        prints only headers, even if --slug and/or --rename is used
+        prints only headers, even if --slugify and/or --rename is used
         """
 
         # no different than basic default behavior
@@ -231,7 +247,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
                 "index,field",
                 "1,a",
                 "2,b_sharps",
-                "3,c_sea_shells",
+                "3,sea_shells",
             ],
         )
 
@@ -248,12 +264,12 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
 
         # when sed
         self.assertLines(
-            ["-P", "--sed", "(a|c)", r"Sed, \1", "examples/dummy.csv"],
+            ["-P", "-X", "(a|c)", r"Foo, \1", "examples/dummy.csv"],
             [
                 "index,field",
-                '1,"Sed, a"',
+                '1,"Foo, a"',
                 "2,b",
-                '3,"Sed, c"',
+                '3,"Foo, c"',
             ],
         )
 
@@ -263,7 +279,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
 
     def test_make_headers_no_added_effect_to_add_headers(self):
         self.assertLines(
-            ["--HM", "--HA", "examples/dummy.csv"],
+            ["--HZ", "--HA", "examples/dummy.csv"],
             [
                 "field_1,field_2,field_3",
                 "a,b,c",
@@ -273,7 +289,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
 
     def test_make_headers_precedence_over_rename(self):
         self.assertLines(
-            ["--HM", "--rename", "field_1|x,field_2|y,field_3|z", "examples/dummy.csv"],
+            ["--HZ", "--rename", "field_1|x,field_2|y,field_3|z", "examples/dummy.csv"],
             ["x,y,z", "1,2,3"],
         )
 
@@ -283,17 +299,17 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
             [
                 "-S",
                 "--rename",
-                'a|apples,"b|B-Sharps!","c|Sea, shells "',
+                'a|Alice,"b|big-bob!","c| CA. "',
                 "examples/dummy.csv",
             ],
-            ["apples,b_sharps,sea_shells", "1,2,3"],
+            ["alice,big_bob,ca", "1,2,3"],
         )
 
     def test_rename_then_sed(self):
         """renaming always happens first, then the slugging"""
         self.assertLines(
             [
-                "--sed",
+                "-X",
                 "(a|b)",
                 r"!\1!",
                 "-R",
@@ -306,7 +322,7 @@ class TestCSVHeaders(CSVKitTestCase, EmptyFileTests):
     def test_sed_then_slug(self):
         """renaming always happens first, then the slugging"""
         self.assertLines(
-            ["-S", "--sed", "(c|b)", r" F O \1 O ", "examples/dummy.csv"],
+            ["-S", "-X", "(c|b)", r" F O \1 O ", "examples/dummy.csv"],
             ["a,f_o_b_o,f_o_c_o", "1,2,3"],
         )
 
