@@ -5,7 +5,7 @@ import sys
 
 from unittest import skip as skiptest
 from unittest.mock import patch
-from tests.tk import CSVKitTestCase, ColumnsTests, EmptyFileTests
+from tests.tk import CSVKitTestCase, ColumnsTests, EmptyFileTests, stdin_as_string
 
 from csvmedkit.exceptions import ColumnIdentifierError
 from csvmedkit.moreutils.csvsed import CSVSed, launch_new_instance
@@ -233,9 +233,8 @@ class TestCSVSed(CSVKitTestCase, ColumnsTests, EmptyFileTests):
             [
                 "-c",
                 "col_a,col_b",
-                r"^(.{1,2})$",
-                r"\1\1",
-                "examples/ab.csv",
+                r"^(.{1,2})$",  # first pattern
+                r"\1\1",  # second pattern
                 "-E",
                 r"^(.{4})$",
                 r"_\1_",
@@ -244,6 +243,7 @@ class TestCSVSed(CSVKitTestCase, ColumnsTests, EmptyFileTests):
                 r"^(.{6})",
                 r"\1, oxford and etc.",
                 "col_a",
+                "examples/ab.csv",
             ],
             [
                 "id,col_a,col_b",
@@ -314,59 +314,126 @@ class TestCSVSed(CSVKitTestCase, ColumnsTests, EmptyFileTests):
             ],
         )
 
-    ##############################
-    # error stuff
-    ##############################
+    ######################################
+    # test intermixed args
+    ######################################
 
-    def test_error_when_expression_has_0_args(self):
-        ioerr = StringIO()
-        with contextlib.redirect_stderr(ioerr):
-            with self.assertRaises(SystemExit) as e:
-                u = self.get_output(
-                    ["-E", "-m", "pattern", "repl", "examples/dummy.csv"]
-                )
-
-        self.assertEqual(e.exception.code, 2)
-        self.assertIn(
-            f"-E/--expr takes 2 or 3 arguments; you provided 0:", ioerr.getvalue()
+    def test_intermix_just_required_args(self):
+        """input_file always has to come after pattern and replace"""
+        self.assertLines(
+            [r"(\w)", r"\1!", "examples/dummy.csv"],
+            [
+                "a,b,c",
+                "1!,2!,3!",
+            ],
         )
 
-    def test_error_when_expression_has_1_arg(self):
-        ioerr = StringIO()
-        with contextlib.redirect_stderr(ioerr):
-            with self.assertRaises(SystemExit) as e:
-                u = self.get_output(
-                    ["-E", "a", "-m", "pattern", "repl", "examples/dummy.csv"]
-                )
-
-        self.assertEqual(e.exception.code, 2)
-        self.assertIn(
-            "-E/--expr takes 2 or 3 arguments; you provided 1: ['a']", ioerr.getvalue()
+    def test_intermix_columns_option(self):
+        # -c option before required args
+        self.assertLines(
+            [
+                "-c",
+                "a,c",
+                r"(\w)",
+                r"\1!",
+                "examples/dummy.csv",
+            ],
+            [
+                "a,b,c",
+                "1!,2,3!",
+            ],
         )
 
-    def test_error_when_expression_has_more_than_3_args(self):
-        ioerr = StringIO()
-        with contextlib.redirect_stderr(ioerr):
-            with self.assertRaises(SystemExit) as e:
-                u = self.get_output(
-                    [
-                        "pattern",
-                        "repl",
-                        "examples/dummy.csv",
-                        "-E",
-                        "a",
-                        "b",
-                        "c",
-                        "d",
-                    ]
-                )
-
-        self.assertEqual(e.exception.code, 2)
-        self.assertIn(
-            "-E/--expr takes 2 or 3 arguments; you provided 4: ['a', 'b', 'c', 'd']",
-            ioerr.getvalue(),
+        # -c option after required args
+        self.assertLines(
+            [r"(\w)", r"\1!", "examples/dummy.csv", "-c", "a,c"],
+            [
+                "a,b,c",
+                "1!,2,3!",
+            ],
         )
 
+        # -c option mixed up in there
+        self.assertLines(
+            [
+                r"(\w)",
+                "-c",
+                "a,c",
+                r"\1!",
+                "examples/dummy.csv",
+            ],
+            [
+                "a,b,c",
+                "1!,2,3!",
+            ],
+        )
+
+    def test_intermix_just_required_args_and_explicit_stdin(self):
+        infile = StringIO("a,b,c\n1,2,3\n")
+        with stdin_as_string(infile):
+            self.assertLines(
+                [
+                    r"(\w)",
+                    r"\1!",
+                    "-",
+                ],
+                [
+                    "a,b,c",
+                    "1!,2!,3!",
+                ],
+            )
+            infile.close()
+
+        # -c option in the middle of stuff
+        infile = StringIO("a,b,c\n1,2,3\n")
+        with stdin_as_string(infile):
+            self.assertLines(
+                [
+                    r"(\w)",
+                    r"\1!",
+                    "-c",
+                    "a,c",
+                    "-",
+                ],
+                [
+                    "a,b,c",
+                    "1!,2,3!",
+                ],
+            )
+            infile.close()
+
+    def test_intermix_just_required_args_and_implicit_stdin(self):
+        infile = StringIO("a,b,c\n1,2,3\n")
+        with stdin_as_string(infile):
+            self.assertLines(
+                [
+                    r"(\w)",
+                    r"\1!",
+                ],
+                [
+                    "a,b,c",
+                    "1!,2!,3!",
+                ],
+            )
+            infile.close()
+
+        # -c option in the middle of stuff
+        infile = StringIO("a,b,c\n1,2,3\n")
+        with stdin_as_string(infile):
+            self.assertLines(
+                [
+                    r"(\w)",
+                    r"\1!",
+                    "-c",
+                    "a,c",
+                ],
+                [
+                    "a,b,c",
+                    "1!,2,3!",
+                ],
+            )
+            infile.close()
+
     def test_no_error_when_expression_has_2_args_and_piped_input(self):
         p1 = Popen(
             [
@@ -382,29 +449,9 @@ class TestCSVSed(CSVKitTestCase, ColumnsTests, EmptyFileTests):
         p2.wait()
         self.assertEqual(txt.splitlines(), ["a,b,c", "1x,2x,3"])
 
-    @skiptest("because I dont know how to deal with stdin.isatty holdup")
-    def test_error_when_final_expression_eats_up_input_path(self):
-        ioerr = StringIO()
-        old_stdin = sys.stdin
-
-        with contextlib.redirect_stderr(ioerr):
-            # with self.assertRaises(SystemExit) as e:
-            args = ["-E", "1", "2", "examples/dummy.csv"]
-            # p = Process(target=self.get_output, args=(args,))
-            # p.start()
-            sys.stdin = StringIO("a,b,c\n1,2,3\n")
-            # p.join()
-
-            self.assertIn("WARNING", ioerr.getvalue())
-
-        # self.assertEqual(e.exception.code, 2)
-        # clean up stdin
-        sys.stdin = oldstdin
-        exit
-
-    ###############
+    ##############################
     # special stuff
-    ###############
+    ##############################
 
     def test_pattern_arg_has_leading_hyphen_causes_error(self):
         ioerr = StringIO()
@@ -475,34 +522,3 @@ class TestCSVSed(CSVKitTestCase, ColumnsTests, EmptyFileTests):
                 '006,grapes,"154,321.98","-X32,654"',
             ],
         )
-
-    ################################################
-    # examples
-
-    def test_example_intro(self):
-        r"""
-        $ csvsed "Ab[bi].+" "Abby" -E "(B|R)ob.*" "\1ob" -E "(?:Jack|John).*" "John"  examples/aliases.csv
-        """
-        self.assertLines(
-            [
-                r"Ab[bi].+",
-                "Abby",
-                "-E",
-                r"(B|R)ob.*",
-                r"\1ob",
-                "-E",
-                r"(?:Jack|John).*",
-                r"John",
-                "examples/aliases.csv",
-            ],
-            [
-                "id,to,from",
-                "1,Abby,Bob",
-                "2,Bob,John",
-                "3,Abby,John",
-                "4,John,Abner",
-                "5,Rob,John",
-                "6,Jon,Abby",
-                "7,Rob,Abby",
-            ],
-        )
